.. -*-restructuredtext-*-

.. image:: https://travis-ci.org/azavea/django-tinsel.svg?branch=master
    :target: https://travis-ci.org/azavea/django-tinsel
.. image:: https://coveralls.io/repos/azavea/django-tinsel/badge.png?branch=master
    :target: https://coveralls.io/r/azavea/django-tinsel

A set of function decorators and utilities for use with Django function-based views
